use strict;
use warnings;
package DZ1;

sub main {
  return 1;
}

1;
__END__

=head1 NAME

DZ1 - this is a sample package for testing Dist::Zilla;

=head1 HEY, MAINTAINER

Note that we have C<< =head1 NAME >> here, and not an ABSTRACT comment.  That's
to exercize C<abstract_from_file>.

  -- rjbs, 2011-11-18

=cut
